==> apache-reef-0.14.0.tar.gz: apache-reef-0.14.0/lang/cs/Org.Apache.REEF.Driver/Bridge/Clr2java/IAllocatedEvaluatorClr2Java.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using Org.Apache.REEF.Driver.Evaluator;
using Org.Apache.REEF.Utilities.Attributes;

namespace Org.Apache.REEF.Driver.Bridge.Clr2java
{
    [Private, Interop("AllocatedEvaluatorClr2Java.cpp", "Clr2JavaImpl.h")]
    public interface IAllocatedEvaluatorClr2Java : IClr2Java
    {
        void SubmitContextAndTask(string contextConfigStr, string taskConfigStr);

        void SubmitContext(string contextConfigStr);

        void SubmitContextAndService(string contextConfigStr, string serviceConfigStr);

        void SubmitContextAndServiceAndTask(string contextConfigStr, string serviceConfigStr, string taskConfigStr);

        void Close();

        string GetId();

        string GetNameServerInfo();

        IEvaluatorDescriptor GetEvaluatorDescriptor();
    }
}

==> apache-reef-0.16.1.tar.gz: apache-reef-0.16.1/lang/cs/Org.Apache.REEF.Driver/Bridge/Clr2java/IAllocatedEvaluatorClr2Java.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using Org.Apache.REEF.Driver.Evaluator;
using Org.Apache.REEF.Utilities.Attributes;

namespace Org.Apache.REEF.Driver.Bridge.Clr2java
{
    [Private, Interop("AllocatedEvaluatorClr2Java.cpp", "Clr2JavaImpl.h")]
    public interface IAllocatedEvaluatorClr2Java : IClr2Java
    {
        void SubmitContextAndTask(string evaluatorConfigStr, string contextConfigStr, string taskConfigStr);

        void SubmitContext(string evaluatorConfigStr, string contextConfigStr);

        void SubmitContextAndService(string evaluatorConfigStr, string contextConfigStr, string serviceConfigStr);

        void SubmitContextAndServiceAndTask(
            string evaluatorConfigStr, string contextConfigStr, string serviceConfigStr, string taskConfigStr);

        void Close();

        string GetId();

        string GetNameServerInfo();

        IEvaluatorDescriptor GetEvaluatorDescriptor();
    }
}
